=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_, and this project adheres to `Calendar Versioning`_.

`Unreleased`_
-------------

`2022.01.05`_
-------------

Removed
^^^^^^^
* Dropped python36 support

`2021.10.22`_
-------------

Added
^^^^^
* Added python310 support
* Added VED

Changed
^^^^^^^
* Changed versioning scheme to calendar versioning

`1.1.0`_ - 2020-08-31
---------------------

Added
^^^^^
* Add support for python 3.6

`1.0.1`_ - 2019-11-21
---------------------

Fixed
^^^^^
* Fixed some typos

`1.0.0`_ - 2019-11-14
---------------------

Added
^^^^^
* Added currency ISO codes (ISO-4217)
* Added country ISO codes (ISO-3166)


.. _`unreleased`: https://github.com/spapanik/teritorio/compare/v2021.10.22...master
.. _`2022.01.05`: https://github.com/spapanik/teritorio/compare/v2021.10.22...v2022.01.05
.. _`2021.10.22`: https://github.com/spapanik/teritorio/compare/v1.1.0...v2021.10.22
.. _`1.1.0`: https://github.com/spapanik/teritorio/compare/v1.0.1...v1.1.0
.. _`1.0.1`: https://github.com/spapanik/teritorio/compare/v1.0.0...v1.0.1
.. _`1.0.0`: https://github.com/spapanik/teritorio/releases/tag/v1.0.0

.. _`Keep a Changelog`: https://keepachangelog.com/en/1.0.0/
.. _`Calendar Versioning`: https://calver.org
